define({
    nl: {
        'Allowed values:'             : 'Toegestane waarden:',
        'Compare all with predecessor': 'Vergelijk alle met voorgaande versie',
        'compare changes to:'         : 'vergelijk veranderingen met:',
        'compared to'                 : 'vergelijk met',
        'Default value:'              : 'Standaard waarde:',
        'Description'                 : 'Omschrijving',
        'Field'                       : 'Veld',
        'General'                     : 'Algemeen',
        'Generated with'              : 'Gegenereerd met',
        'Name'                        : 'Naam',
        'No response values.'         : 'Geen response waardes.',
        'optional'                    : 'optioneel',
        'Parameter'                   : 'Parameter',
        'Permission:'                 : 'Permissie:',
        'Response'                    : 'Antwoorden',
        'Send'                        : 'Sturen',
        'Send a Sample Request'       : 'Stuur een sample aanvragen',
        'show up to version:'         : 'toon tot en met versie:',
        'Size range:'                 : 'Maatbereik:',
        'Type'                        : 'Type',
        'url'                         : 'url'
    }
});
