define({
    es: {
        'Allowed values:'             : 'Valores permitidos:',
        'Compare all with predecessor': 'Comparar todo con versión anterior',
        'compare changes to:'         : 'comparar cambios con:',
        'compared to'                 : 'comparado con',
        'Default value:'              : 'Valor por defecto:',
        'Description'                 : 'Descripción',
        'Field'                       : 'Campo',
        'General'                     : 'General',
        'Generated with'              : 'Generado con',
        'Name'                        : 'Nombre',
        'No response values.'         : 'Sin valores en la respuesta.',
        'optional'                    : 'opcional',
        'Parameter'                   : 'Parámetro',
        'Permission:'                 : 'Permisos:',
        'Response'                    : 'Respuesta',
        'Send'                        : 'Enviar',
        'Send a Sample Request'       : 'Enviar una petición de ejemplo',
        'show up to version:'         : 'mostrar a versión:',
        'Size range:'                 : 'Tamaño de rango:',
        'Type'                        : 'Tipo',
        'url'                         : 'url'
    }
});
