define({
    de: {
        'Allowed values:'             : 'Erlaubte Werte:',
        'Compare all with predecessor': 'Vergleiche alle mit ihren Vorgängern',
        'compare changes to:'         : 'vergleiche Änderungen mit:',
        'compared to'                 : 'verglichen mit',
        'Default value:'              : 'Standardwert:',
        'Description'                 : 'Beschreibung',
        'Field'                       : 'Feld',
        'General'                     : 'Allgemein',
        'Generated with'              : 'Erstellt mit',
        'Name'                        : 'Name',
        'No response values.'         : 'Keine Rückgabewerte.',
        'optional'                    : 'optional',
        'Parameter'                   : 'Parameter',
        'Permission:'                 : 'Berechtigung:',
        'Response'                    : 'Antwort',
        'Send'                        : 'Senden',
        'Send a Sample Request'       : 'Eine Beispielanfrage senden',
        'show up to version:'         : 'zeige bis zur Version:',
        'Size range:'                 : 'Größenbereich:',
        'Type'                        : 'Typ',
        'url'                         : 'url'
    }
});
