define({
    pl: {
        'Allowed values:'             : 'Dozwolone wartości:',
        'Compare all with predecessor': 'Porównaj z poprzednimi wersjami',
        'compare changes to:'         : 'porównaj zmiany do:',
        'compared to'                 : 'porównaj do:',
        'Default value:'              : 'Wartość domyślna:',
        'Description'                 : 'Opis',
        'Field'                       : 'Pole',
        'General'                     : 'Generalnie',
        'Generated with'              : 'Wygenerowano z',
        'Name'                        : 'Nazwa',
        'No response values.'         : 'Brak odpowiedzi.',
        'optional'                    : 'opcjonalny',
        'Parameter'                   : 'Parametr',
        'Permission:'                 : 'Uprawnienia:',
        'Response'                    : 'Odpowiedź',
        'Send'                        : 'Wyślij',
        'Send a Sample Request'       : 'Wyślij przykładowe żądanie',
        'show up to version:'         : 'pokaż do wersji:',
        'Size range:'                 : 'Zakres rozmiaru:',
        'Type'                        : 'Typ',
        'url'                         : 'url'
    }
});
