define({
    ru: {
        'Allowed values:'             : 'Допустимые значения:',
        'Compare all with predecessor': 'Сравнить с предыдущей версией',
        'compare changes to:'         : 'сравнить с:',
        'compared to'                 : 'в сравнении с',
        'Default value:'              : 'По умолчанию:',
        'Description'                 : 'Описание',
        'Field'                       : 'Название',
        'General'                     : 'Общая информация',
        'Generated with'              : 'Сгенерировано с помощью',
        'Name'                        : 'Название',
        'No response values.'         : 'Нет значений для ответа.',
        'optional'                    : 'необязательный',
        'Parameter'                   : 'Параметр',
        'Permission:'                 : 'Разрешено:',
        'Response'                    : 'Ответ',
        'Send'                        : 'Отправить',
        'Send a Sample Request'       : 'Отправить тестовый запрос',
        'show up to version:'         : 'показать версию:',
        'Size range:'                 : 'Ограничения:',
        'Type'                        : 'Тип',
        'url'                         : 'URL'
    }
});
