define({
    it: {
        'Allowed values:'             : 'Valori permessi:',
        'Compare all with predecessor': 'Confronta tutto con versioni precedenti',
        'compare changes to:'         : 'confronta modifiche con:',
        'compared to'                 : 'confrontato con',
        'Default value:'              : 'Valore predefinito:',
        'Description'                 : 'Descrizione',
        'Field'                       : 'Campo',
        'General'                     : 'Generale',
        'Generated with'              : 'Creato con',
        'Name'                        : 'Nome',
        'No response values.'         : 'Nessun valore di risposta.',
        'optional'                    : 'opzionale',
        'Parameter'                   : 'Parametro',
        'Permission:'                 : 'Permessi:',
        'Response'                    : 'Risposta',
        'Send'                        : 'Invia',
        'Send a Sample Request'       : 'Invia una richiesta di esempio',
        'show up to version:'         : 'mostra alla versione:',
        'Size range:'                 : 'Intervallo dimensione:',
        'Type'                        : 'Tipo',
        'url'                         : 'url'
    }
});
