define({
    ca: {
        'Allowed values:'             : 'Valors permesos:',
        'Compare all with predecessor': 'Comparar tot amb versió anterior',
        'compare changes to:'         : 'comparar canvis amb:',
        'compared to'                 : 'comparat amb',
        'Default value:'              : 'Valor per defecte:',
        'Description'                 : 'Descripció',
        'Field'                       : 'Camp',
        'General'                     : 'General',
        'Generated with'              : 'Generat amb',
        'Name'                        : 'Nom',
        'No response values.'         : 'Sense valors en la resposta.',
        'optional'                    : 'opcional',
        'Parameter'                   : 'Paràmetre',
        'Permission:'                 : 'Permisos:',
        'Response'                    : 'Resposta',
        'Send'                        : 'Enviar',
        'Send a Sample Request'       : 'Enviar una petició d\'exemple',
        'show up to version:'         : 'mostrar versió:',
        'Size range:'                 : 'Tamany de rang:',
        'Type'                        : 'Tipus',
        'url'                         : 'url'
    }
});
